aboutsummaryrefslogtreecommitdiff
path: root/include/llvm/Analysis/DataStructure/DSGraph.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/Analysis/DataStructure/DSGraph.h')
-rw-r--r--include/llvm/Analysis/DataStructure/DSGraph.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/include/llvm/Analysis/DataStructure/DSGraph.h b/include/llvm/Analysis/DataStructure/DSGraph.h
index eb4388b6ad..61853587d7 100644
--- a/include/llvm/Analysis/DataStructure/DSGraph.h
+++ b/include/llvm/Analysis/DataStructure/DSGraph.h
@@ -378,9 +378,12 @@ public:
/// print - Print a dot graph to the specified ostream...
///
+ void print(llvm_ostream &O) const {
+ if (O.stream()) print(*O.stream());
+ }
void print(std::ostream &O) const;
/// dump - call print(std::cerr), for use from the debugger...
///
void dump() const;
@@ -378,9 +378,12 @@ public:
void print(std::ostream &O) const;
- /// dump - call print(std::cerr), for use from the debugger...
+ /// dump - call print(llvm_cerr), for use from the debugger...
///
void dump() const;